@@ -1,7 +1,8 @@
 from zope.interface import implements
 from zope.publisher.browser import TestRequest
 
-from Products.Five import zcml
+# from Products.Five import zcml
+from Zope2.App import zcml
 from Products.Five import fiveconfigure
 
 from Products.PloneTestCase import PloneTestCase as ptc
